@@ -1,5 +1,3 @@
-/*	$Id: vilter-attachment.c,v 1.63 2007/01/06 13:13:25 mbalmer Exp $	*/
-
 /*
  * Copyright (c) 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
  *
@@ -37,7 +35,7 @@
 #include <netdb.h>
 #include <err.h>
 #include <syslog.h>
-#include <regex.h>
+#include <fnmatch.h>
 
 #include "pathnames.h"
 #include "smtp-vilter.h"
@@ -320,8 +318,7 @@ analyze_part(struct part *p, char *eom, char *pattern, size_t patlen)
 					/* warnx("Content-Type: %s", ctype); */
 
 					SLIST_FOREACH(pat, &ctype_pats, pats) {
-						if (regexec(&pat->preg, ctype,
-						    0, NULL, 0) == 0) {
+						if (!fnmatch(ctype, pat->pat, pat->flags)) {
 							p->skip = skip = 1;
 							strlcpy(pattern,
 							    "content-type "
@@ -363,9 +360,7 @@ analyze_part(struct part *p, char *eom, char *pattern, size_t patlen)
 					    a->value_len);
 					filename[a->value_len] = 0;
 					SLIST_FOREACH(pat, &fname_pats, pats) {
-						if (regexec(&pat->preg,
-						    filename, 0, NULL, 0) ==
-						    0) {
+						if (!fnmatch(filename, pat->pat, pat->flags)) {
 							p->skip = skip = 1;
 							strlcpy(pattern,
 							    "filname pattern: ",
@@ -457,9 +452,10 @@ vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *reason,
 		if (inhdr == 1) {
 			if (strncmp(m, "Content-Type: ",
 			    strlen("Content-Type: ")) == 0) {
-				for (q = m; q < eom && isspace(*q) == 0; q++)
+				for (q = m; q < eom && isspace((int)*q) == 0;
+				    q++)
 					;
-				while (q < eom && isspace(*q))
+				while (q < eom && isspace((int)*q))
 					q++;
 
 				if (strncmp(q, "multipart",
@@ -480,7 +476,7 @@ vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *reason,
 					/* See RFC-2046 for characters allowed in a boundary */
 
 					for (q = boundary, boundary_len = 0; q < eom && (
-						isalpha(*q) || isdigit(*q) ||
+						isalpha((int)*q) || isdigit((int)*q) ||
 						*q == '\'' || *q == '(' || *q == ')' ||
 						*q == '+' || *q == '_' || *q == ',' ||
 						*q == '-' || *q == '.' || *q == '/' ||
@@ -510,7 +506,7 @@ vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *reason,
 				/* end of message */ ;
 			} else {
 				p = malloc(sizeof(struct part));
-				if (p == NULL)
+				if (p == NULL) {
 					syslog(LOG_ERR, "attachment: memory allocation error, not all message parts will be written");
 					goto line;
 				}
@@ -524,6 +520,7 @@ vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *reason,
 					free(p);
 					p = NULL;
 				}
+			}
 		}
 line:
 		++lines;
@@ -630,7 +627,6 @@ vilter_exit(void)
 	while (!SLIST_EMPTY(&fname_pats)) {
 		p = SLIST_FIRST(&fname_pats);
 		SLIST_REMOVE_HEAD(&fname_pats, pats);
-		regfree(&p->preg);
 		free(p->pat);
 		free(p);
 	}
@@ -638,7 +634,6 @@ vilter_exit(void)
 	while (!SLIST_EMPTY(&ctype_pats)) {
 		p = SLIST_FIRST(&ctype_pats);
 		SLIST_REMOVE_HEAD(&ctype_pats, pats);
-		regfree(&p->preg);
 		free(p->pat);
 		free(p);
 	}
