@@ -1,5 +1,3 @@
-/*	$Id: vilter-attachment.h,v 1.3 2006/02/19 17:07:46 mbalmer Exp $ */
-
 /*
  * Copyright (c) 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
  *
@@ -20,6 +18,6 @@ SLIST_HEAD(pat_head, pattern);
 
 struct pattern {
 	char	*pat;
-	regex_t	 preg;
+	int	 flags;
 	SLIST_ENTRY(pattern) pats;
 };
