@@ -1,7 +1,5 @@
-/*	$Id: engine.c,v 1.66 2007/01/21 13:09:15 mbalmer Exp $	*/
-
 /*
- * Copyright (c) 2003, 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
+ * Copyright (c) 2003 - 2013 Marc Balmer <marc@msys.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -20,6 +18,7 @@
 #include <sys/types.h>
 #include <sys/queue.h>
 #include <sys/resource.h>
+#include <sys/signal.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
 
@@ -52,7 +51,6 @@
 #include <sys/param.h>
 #include <sys/poll.h>
 #include "strlfunc.h"
-#include "strtonum.h"
 #else
 #include <poll.h>
 #include <sys/syslimits.h>
@@ -97,8 +95,6 @@ extern FILE	*logfp;
 extern char	*user;
 extern char	*group;
 extern char	*chrootdir;
-extern rlim_t	 rlimit_nofile;
-extern rlim_t	 rlimit_nproc;
 extern int	 nbe;
 extern char	*spamprefix;
 extern char	*spam_headerf;
@@ -173,6 +169,14 @@ struct privdata {
 	struct stats_msg 	 stats;
 };
 
+enum tokens {
+	ViBACKEND_TYPE = 1,
+	ViSTOP_CHAIN,
+	ViSTRATEGY,
+	ViREACTION,
+	ViPF_TABLE,
+};
+	
 #ifdef ENABLE_PF
 static void pf_table_add(const char *, const char *);
 static void pf_table_clr(const char *, const char *);
@@ -501,18 +505,62 @@ smtp_vilter_envfrom(SMFICTX *ctx, char **argv)
 		}
 	}
 
+	/* report authentication symbol values */
+	if (verbose >= 2)
+		warnx("SASL authentication parameters: {auth_type}=%s, "
+		    "{auth_authen}=%s, {auth_ssf}=%s, {auth_author}=%s",
+		    smfi_getsymval(ctx, "{auth_type}"),
+		    smfi_getsymval(ctx, "{auth_authen}"),
+		    smfi_getsymval(ctx, "{auth_ssf}"),
+		    smfi_getsymval(ctx, "{auth_author}"));
+
 	/* Write an artifical Received: from: Header to the message */
 	if (gethostname(hostname, sizeof(hostname))) {
 		syslog(LOG_ERR, "can't get local hostname");
 		strlcpy(hostname, "localhost", sizeof(hostname));
 	}
-	if (conn->clientaddr == NULL)
-		fprintf(msg->fp, "Received: from %s by %s\r\n", conn->hostname,
-		    hostname);
-	else
-		fprintf(msg->fp, "Received: from %s (%s) by %s\r\n",
-		    conn->heloname, conn->clientaddr, hostname);
+	if (verbose >= 2)
+		warnx("header_options = 0x%lx", header_options);
+	if (header_options == 0x0L) {
+		/* plain 'Received:' header (legacy behaviour) */
+		if (conn->clientaddr == NULL)
+			fprintf(msg->fp, "Received: from %s by %s\r\n",
+			    conn->hostname, hostname);
+		else
+			fprintf(msg->fp, "Received: from %s (%s) by %s\r\n",
+			    conn->heloname, conn->clientaddr, hostname);
+	}
 
+	if (header_options & 0x1L) {
+		/* include SASL auth info in 'Received:' header */
+		if (verbose >= 2)
+			warnx("including SASL auth info in header");
+		if (smfi_getsymval(ctx, "{auth_authen}") != NULL) {
+			/* SASL authenticated sender */
+			if (conn->clientaddr == NULL)
+				fprintf(msg->fp, "Received: from %s "
+				    "(Authenticated sender: %s) by %s\r\n",
+				    conn->hostname,
+				    smfi_getsymval(ctx, "{auth_authen}"),
+				    hostname);
+			else
+				fprintf(msg->fp, "Received: from %s (%s) "
+				    "(Authenticated sender: %s) by %s\r\n",
+				    conn->heloname,
+				    conn->clientaddr,
+				    smfi_getsymval(ctx, "{auth_authen}"),
+				    hostname);
+		} else {
+			/* non authenticated sender */
+			if (conn->clientaddr == NULL)
+				fprintf(msg->fp, "Received: from %s by %s\r\n",
+				    conn->hostname, hostname);
+			else
+				fprintf(msg->fp, "Received: from %s (%s) by %s\r\n",
+				    conn->heloname, conn->clientaddr, hostname);
+		}
+	}
+		
 	return SMFIS_CONTINUE;
 }
 
@@ -777,7 +825,7 @@ mark_spam(SMFICTX *ctx, char *status, char *backend, double score,
 	snprintf(hdr, sizeof(hdr), "%.1f", score);
 	smfi_addheader(ctx, "X-Spam-Score", hdr);
 
-	lvl = (int) rint(score);
+	lvl = (int)rint(score);
 
 	if (lvl > 0) {
 		if (lvl < strlen(slvl))
@@ -886,8 +934,8 @@ log_incident(struct privdata *priv, char *type, char *backend, char *value)
 	if (logfp == NULL)
 		return;
 
-	flockfile(logfp);
 	time(&now);
+	flockfile(logfp);
 	fprintf(logfp, "smtp-vilter incident report\n");
 	fprintf(logfp, "timestamp: %s", ctime(&now));
 	fprintf(logfp, "type: %s\n", type);
@@ -1023,7 +1071,6 @@ vilter_virus(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 	case SCAN_ERROR:
 		++priv->stats.err;
 		syslog(LOG_ERR, "error during virus scan of file %s", msg->tfn);
-
 		switch (error_strategy) {
 		case STRATEGY_IGNORE:
 			syslog(LOG_INFO, "ignoring the error");
@@ -1031,7 +1078,6 @@ vilter_virus(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 			break;
 		case STRATEGY_MARK:
 			syslog(LOG_INFO, "marking message (deliver anyway)");
-
 			mark_virus(ctx, "unchecked", NULL, backend->name);
 			retval = SMFIS_CONTINUE;
 			break;
@@ -1047,7 +1093,6 @@ vilter_virus(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 		}
 		break;
 	}
-			
 	return retval;
 }
 
@@ -1326,37 +1371,6 @@ vilter_unwanted(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 	return retval;
 }
 
-#ifdef ENABLE_LDAP
-static void
-print_entries_with_values(LDAP *ld, LDAPMessage *result)
-{
-	LDAPMessage	*e;
-	BerElement	*ber;
-	char		*dn, *attr;
-	char		**vals;
-	int		 i;
-
-	for (e = ldap_first_entry(ld, result); e != NULL;
-	    e = ldap_next_entry(ld, e)) {
-		if ((dn = ldap_get_dn(ld, e)) != NULL) {
-			if (verbose)
-				warnx("dn: %s", dn);
-			ldap_memfree(dn);
-		}
-		for (attr = ldap_first_attribute(ld, e, &ber); attr != NULL;
-		    attr = ldap_next_attribute(ld, e, ber)) {
-			if ((vals = ldap_get_values(ld, e, attr)) != NULL) {
-				for (i = 0; vals[i] != NULL; i++)
-					printf("%s: %s\n", attr, vals[i]);
-				ldap_value_free(vals);
-			}
-			ldap_memfree(attr);
-		}
-		ber_free(ber, 0);
-	}
-}
-#endif
-
 static sfsistat
 vilter_eom(SMFICTX *ctx)
 {
@@ -1565,7 +1579,6 @@ vilter_eom(SMFICTX *ctx)
 	}	
 #endif
 	message_cleanup(ctx);
-		
 	return retval;
 }
 
@@ -1635,13 +1648,13 @@ pf_table_add(const char *table, const char *addr)
 
 	if (table == NULL || addr == NULL)
 		return;
-	
+
 	pid = getpid();
 
 	strlcpy(m.pftable, table, PFTABLE_LEN);
 	strlcpy(m.addr, addr, ADR_LEN);
 	m.len = 0;
-	
+
 	if (imsg_compose(ibuf_main, IMSG_PFTABLE_ADD, 0, pid, -1, &m,
 	    sizeof(m)) != -1) 
 		imsg_commit();
@@ -1655,13 +1668,13 @@ pf_table_clr(const char *table, const char *addr)
 
 	if (table == NULL || addr == NULL)
 		return;
-	
+
 	pid = getpid();
 
 	strlcpy(m.pftable, table, PFTABLE_LEN);
 	strlcpy(m.addr, addr, ADR_LEN);
 	m.len = 0;
-	
+
 	if (imsg_compose(ibuf_main, IMSG_PFTABLE_DEL, 0, pid, -1, &m,
 	    sizeof(m)) != -1)
 		imsg_commit();
@@ -1696,7 +1709,6 @@ int
 e_main(uid_t uid, gid_t gid, int pipe_m2e[2])
 {
 	smfiDesc_str	 desc;
-	struct rlimit	 rl;
 	int		 pid;
 
 	switch (pid = fork()) {
@@ -1715,24 +1727,6 @@ e_main(uid_t uid, gid_t gid, int pipe_m2e[2])
 
 	signal(SIGUSR1, SIG_IGN);
 
-	/* Set ressource limits */
-
-	if (rlimit_nofile > 0) {
-		rl.rlim_cur = rl.rlim_max = rlimit_nofile;
-
-		if (setrlimit(RLIMIT_NOFILE, &rl))
-			err(1, "can set number of files to %lld",
-			    (long long)rlimit_nofile);
-	}
-
-	if (rlimit_nproc > 0) {
-		rl.rlim_cur = rl.rlim_max = rlimit_nproc;
-
-		if (setrlimit(RLIMIT_NPROC, &rl))
-			err(1, "can set number of processes to %lld",
-			    (long long)rlimit_nproc);
-	}
-
 	if (logfile != NULL && (logfp = fopen(logfile, "a")) == NULL)
 		err(1, "can't open logfile %s", logfile);
 
@@ -1764,6 +1758,8 @@ e_main(uid_t uid, gid_t gid, int pipe_m2e[2])
 	syslog(LOG_INFO, "dropped privileges, running as %d:%d", uid, gid);
 
 	/* Initialize sendmail milter */
+	bzero(&desc, sizeof(desc));
+
 	desc.xxfi_name = "smtp-vilter";
 	desc.xxfi_version = SMFI_VERSION;
 	desc.xxfi_flags = SMFIF_ADDHDRS | SMFIF_CHGHDRS;
