@@ -1,5 +1,3 @@
-/*	$Id: pathnames.h,v 1.8 2006/11/12 11:38:08 mbalmer Exp $	*/
-
 /*
  * Copyright (c) 2005, 2006 Marc Balmer <marc@msys.ch>
  *
@@ -20,4 +18,8 @@
 #define _PATH_TMPDIR		"/tmp"
 
 #define	_PATH_CFGFILE		"/etc/smtp-vilter/smtp-vilter.conf"
+#ifdef __NetBSD__
+#define _PATH_BACKEND		"/usr/pkg/lib/smtp-vilter"
+#else
 #define _PATH_BACKEND		"/usr/local/lib/smtp-vilter"
+#endif
