@@ -1,7 +1,5 @@
-/*	$Id: smtp-vilter.c,v 1.172 2007/01/21 13:09:15 mbalmer Exp $	*/
-
 /*
- * Copyright (c) 2003 - 2007 Marc Balmer <marc@msys.ch>
+ * Copyright (c) 2003 - 2008 Marc Balmer <marc@msys.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -51,7 +49,6 @@
 #ifdef __linux__
 #include <sys/param.h>
 #include "strlfunc.h"
-#include "strtonum.h"
 #else
 #include <sys/syslimits.h>
 #endif
@@ -82,6 +79,7 @@ char	*clean_table;
 
 int	 markall;
 int	 logall;
+unsigned long header_options;
 int	 verbose;
 char	*cfgfile;
 char	*tmpdir;
@@ -91,7 +89,6 @@ char	*backend;
 char	*backend_path;
 char	*recipient_notification;
 char	*notify_only;
-int	 log_facility;
 char	*logfile;
 char	*statfile;
 time_t	 stat_begin;
@@ -100,8 +97,6 @@ FILE	*logfp;
 char	*user;
 char	*group;
 char	*chrootdir;
-rlim_t	 rlimit_nofile;
-rlim_t	 rlimit_nproc;
 int	 nbe;
 char	*spamprefix;
 char	*spam_headerf;
@@ -188,7 +183,7 @@ static void
 usage(void)
 {
 	fprintf(stderr, "usage: %s"
-	    " [-Vvmkx"
+	    " [-vmkx"
 #ifdef ENABLE_LDAP
 	    "Z[Z]"
 #endif
@@ -205,11 +200,11 @@ usage(void)
 	    " [-D binddn]"
 #endif
 	    " [-e logfile]"
-	    " [-f maxfiles]"
 	    " [-g group]"
 #ifdef ENABLE_LDAP
 	    " [-h ldaphost]"
 #endif
+	    " [-H header-options]"
 	    " [-i interval]"
 #ifdef ENABLE_LDAP
 	    " [-L ldapport]"
@@ -287,7 +282,6 @@ main(int argc, char *argv[])
 	struct group	*grp;
 	uid_t		 uid;
 	gid_t		 gid;
-	struct rlimit	 rl;
 	struct pollfd	 pfd[1];
 	int		 n;
 	pid_t		 child_pid, pid;
@@ -297,8 +291,6 @@ main(int argc, char *argv[])
 	int		 version;
 #endif
 	int		 xmode;
-	const char	*errstr;
-	rlim_t		 rlimit_max;
 	int		 pipe_m2e[2];
 	int		 nfds;
 	int		 flags;
@@ -329,7 +321,6 @@ main(int argc, char *argv[])
 
 	virus_table = spam_table = unwanted_table = clean_table = NULL;
 
-	log_facility = LOG_UNSET;
 	logfile = NULL;
 	statfile = NULL;
 	stat_interval = 0;
@@ -337,8 +328,6 @@ main(int argc, char *argv[])
 	notify_only = NULL;
 	markall = 0;
 	logall = 0;
-	rlimit_nofile = 0;
-	rlimit_nproc = 0;
 	spamprefix = NULL;
 	spam_headerf = NULL;
 	spam_headerv = NULL;
@@ -355,13 +344,12 @@ main(int argc, char *argv[])
 #endif
 	xmode = 0;
 
-	/* Process the commandline */
 #ifdef ENABLE_LDAP	
 	while ((ch = getopt(argc, argv,
-	    "A:a:B:b:C:D:d:e:f:g:h:i:kL:mn:o:p:s:T:t:u:U:Vvw:xZ?")) != -1) {
+	    "A:a:B:b:C:D:d:e:g:h:H:i:kL:mn:o:p:s:T:t:u:U:vw:xZ?")) != -1) {
 #else
 	while ((ch = getopt(argc, argv,
-	    "A:a:b:C:d:e:f:g:i:kmn:o:p:T:t:s:u:VvxZ?")) != -1) {
+	    "A:a:b:C:d:e:g:H:i:kmn:o:p:T:t:s:u:vxZ?")) != -1) {
 #endif
 		switch (ch) {
 		case 'A':
@@ -392,43 +380,27 @@ main(int argc, char *argv[])
 			break;
 		case 'e':
 			logfile = optarg;
-			break;
-		case 'f':
-			if (getuid()) {
-				getrlimit(RLIMIT_NOFILE, &rl);
-				rlimit_max = rl.rlim_max;
-			} else
-				rlimit_max = RLIM_INFINITY;
-			rlimit_nofile = (int)strtonum(optarg, 1LL,
-			    (long long)rlimit_max, &errstr);
-			if (errstr)
-				errx(1, "number of files is %s: %s", errstr,
-				    optarg);
 			break; 
 		case 'g':
 			group = optarg;
 			break;
+		case 'H':
+			header_options = atol(optarg);
+			break;
 #ifdef ENABLE_LDAP
 		case 'h':
 			ldaphost = optarg;
 			break;
 #endif
 		case 'i':
-			stat_interval = (unsigned int)strtonum(optarg, 1LL,
-			    100000000LL, &errstr);
-			if (errstr)
-				errx(1, "statistics dump interval is %s: %s",
-				    errstr, optarg);
+			stat_interval = atol(optarg);
 			break;
 		case 'k':
 			keep_tmpfiles = 1;
 			break;
 #ifdef ENABLE_LDAP
 		case 'L':
-			ldapport = strtonum(optarg, 1, 65535, &errstr);
-			if (errstr)
-				errx(1, "ldap port number is %s: %s", errstr,
-				    optarg);
+			ldapport = atoi(optarg);
 			break;
 #endif
 		case 'm':
@@ -465,12 +437,6 @@ main(int argc, char *argv[])
 			ldapurl = optarg;
 			break;
 #endif
-		case 'V':
-			printf("%s %s\n", __progname, VERSION);
-#ifdef ENABLE_LDAP
-			printf("LDAP support enabled\n");
-#endif
-			exit(0);
 		case 'v':
 			++verbose;
 			break;
@@ -529,8 +495,6 @@ main(int argc, char *argv[])
 		unwanted_strategy = STRATEGY_MARK;
 	if (error_strategy == -1)
 		error_strategy = STRATEGY_TEMPFAIL;
-	if (log_facility == LOG_UNSET)
-		log_facility = LOG_MAIL;
 
 #ifdef ENABLE_LDAP
 	if (ldaphost == NULL)
@@ -557,14 +521,6 @@ main(int argc, char *argv[])
 		printf("port: %s\n", port);
 		printf("tmpdir: %s\n", tmpdir);
 		printf("logfile: %s\n", logfile != NULL ? logfile : "not set");
-		if (rlimit_nofile != 0)
-			printf("maxfiles: %lld\n", (long long)rlimit_nofile);
-		else
-			printf("maxfiles: not set\n"); 
-		if (rlimit_nproc != 0)
-			printf("maxprocs: %lld\n", (long long)rlimit_nproc);
-		else
-			printf("maxprocs: not set\n");
 #ifdef ENABLE_LDAP
 		printf("ldapurl: %s\n", ldapurl != NULL ? ldapurl : "not set");
 		printf("ldaphost: %s\n", ldaphost);
@@ -677,7 +633,7 @@ main(int argc, char *argv[])
 		    ldaphost, ldap_use_tls ? "" : "not ");
 #endif
 	openlog(__progname, verbose ? LOG_CONS | LOG_NDELAY | LOG_PID |
-	    LOG_PERROR : LOG_CONS | LOG_NDELAY | LOG_PID, log_facility);
+	    LOG_PERROR : LOG_CONS | LOG_NDELAY | LOG_PID, LOG_MAIL);
 
 	/* Load the backends */
 	for (n = 0; n < nbe; n++) {
@@ -916,7 +872,7 @@ main(int argc, char *argv[])
 					time(&now);
 					if ((fp = fopen(statfile, "a")) !=
 					    NULL) {
-						fprintf(fp, "%u\t%u\t%u\t%u\t"
+						fprintf(fp, "%ld\t%ld\t%u\t%u\t"
 						    "%u\t%u\t%u\t%u\t%u\n",	
 						    stat_begin, now, n_conn,
 						    n_aborts, n_msgs,
